library(ggplot2)
library(data.table)
library(logr)
library(dplyr)
#library(naniar)
library(formattable)
library(writexl)
library("gridExtra")


#setwd("C:/Users/frederico.malta/Documents/Frederico/Projetos/Coronavirus/artigo_coronavirus/variantes_capitais_sintomas")

#source("sintomas_gov_v2-4.R")

#Arquivo escolhido para a análise baixado no site https://opendatasus.saude.gov.br/dataset/srag-2021-e-2022 em 26-09-2022.

arquivo_analise2021 <- "C:/Users/frederico.malta/Documents/Frederico/Projetos/Coronavirus/artigo_coronavirus/variantes_capitais_sintoma2/INFLUD21-26-09-2022.csv"
arquivo_analise2022 <- "C:/Users/frederico.malta/Documents/Frederico/Projetos/Coronavirus/artigo_coronavirus/variantes_capitais_sintoma2/INFLUD22-26-09-2022.csv"

filename1 <- basename(arquivo_analise2021)
filename2 <- basename(arquivo_analise2022)

filename_ext1 <- sub(".csv", "", filename1)
filename_ext2 <- sub(".csv", "", filename2)


setwd("C:/Users/frederico.malta/Documents/Frederico/Projetos/Coronavirus/artigo_coronavirus/variantes_capitais_sintoma2")
dir.create(paste0(getwd(),"/gov_sintomas"))
setwd(paste0(getwd(),"/gov_sintomas"))

log <- file.path(getwd(), paste0("relatório_", filename_ext1, "_",filename_ext2, ".log")) #cria e abre o arquivo de log
lf <- log_open(log, show_notes = FALSE)


db2021 <- fread(arquivo_analise2021)

log_print(sprintf("Relatório a partir do arquivo %s baixado no site do ministério da saúde https://https://opendatasus.saude.gov.br/dataset/bd-srag-2021", filename1))

db2021$DT_NOTIFIC <- as.Date(db2021$DT_NOTIFIC, format = "%d/%m/%Y")

db1 <- db2021[which(db2021$DT_NOTIFIC >= as.Date("2021-08-29") & db2021$DT_NOTIFIC <= as.Date("2022-03-05") ),]

rm(db2021)

db2022 <- fread(arquivo_analise2022)

log_print(sprintf("Relatório a partir do arquivo %s baixado no site do ministério da saúde https://https://opendatasus.saude.gov.br/dataset/bd-srag-2021", filename2))

db2022$DT_NOTIFIC <- as.Date(db2022$DT_NOTIFIC, format = "%d/%m/%Y")

db2 <- db2022[which(db2022$DT_NOTIFIC >= as.Date("2022-01-01") & db2022$DT_NOTIFIC <= as.Date("2022-03-05") ),]

rm(db2022)

db <- rbind(db1, db2)

write.csv2(db, file = "dataframe_db.csv")


c <- count(db) #Número de linhas antes da limpeza

log_print(sprintf("A tabela apresenta %s linhas antes da limpeza.", c))

rm(db1, db2)

data0 <- db %>% distinct(.keep_all = TRUE)

c0 <- count(data0) #Número de linhas após a retirada de linhas duplicadas

data1 <- data0[!with(data0,is.na(DT_NOTIFIC) | is.na(DT_SIN_PRI) | is.na(CS_SEXO) | is.na(NU_IDADE_N) | is.na(TP_IDADE) | is.na(CS_GESTANT) | is.na(SG_UF) | is.na(CO_MUN_RES) | is.na(CO_MUN_NOT) | is.na(CO_PAIS) | is.na(VACINA_COV) |  is.na(DT_INTERNA) | is.na(CLASSI_FIN) ) ,] #campos obrigatórios

log_print(sprintf("A tabela apresenta %s linhas após a retirada de linhas duplicadas.", c0))

rm(db)

c1 <- count(data1) #Número de linhas após a retirada de linhas que não contém informação nos campos obrigatórios, ou seja, dados incorretos.

log_print(sprintf("A tabela apresenta %s linhas após a retirada de linhas sem informações(NA) nos campos obrigatórios, ou seja, dados incorretos. DT_NOTIFIC, CS_SEXO, CS_GESTANT, HISTO_VGM, CLASSI_FIN e NU_IDADE_N", c1))

rm(data0)
#############################################################################
#Foi aceita esta filtragem pois apenas aproximadamente 37.000 dados foram filtrados no 
# período de interesse 
#
#############################################################################

#data2 <- data1[!with(data1, is.na(FEBRE) | is.na(TOSSE) | is.na(GARGANTA) | is.na(DISPNEIA) | is.na(DESC_RESP) | is.na(SATURACAO) | is.na(DIARREIA) | is.na(VOMITO) | is.na(DOR_ABD) | is.na(FADIGA) | is.na(PERD_OLFT) | is.na(PERD_PALA) | is.na(SUPORT_VEN) | is.na(RAIOX_RES) | is.na(TOMO_RES) | is.na(HOSPITAL) | is.na(UTI) | is.na(EVOLUCAO) ), ] # campos essenciais importantes para o estudo

data2 <- data1[!with(data1,  is.na(SUPORT_VEN) | is.na(HOSPITAL) | is.na(UTI) | is.na(EVOLUCAO) ), ] # campos essenciais importantes para o estudo

c2 <- count(data2) #Número de linhas após a retirada de linhas sem informações(NA) nos campos essenciais ao estudo.

log_print(sprintf("A tabela apresenta %s linhas após a retirada de linhas sem informações(NA) nos campos essenciais. SUPORT_VEN, HOSPITAL, UTI, EVOLUCAO", c2))

#############################################################################
#Optou-se por utilizar apenas os campos SUPORT_VEN, HOSPITAL, UTI e EVOLUCAO
#para manter o máximo de dados possível considerando os aspectos de avaliação
# de gravidade como o suporte ventilatório, hospitalizaçao, uti e morte.
#
#############################################################################

rm(data1)

data3 <- data2[!with(data2, is.na(PCR_RESUL))] # campos essenciais adicionais para o estudo

c3 <- count(data3) #Número de linhas após a retirada de linhas sem informações(NA) nos campos essenciais adicionais para o estudo

log_print(sprintf("A tabela apresenta %s linhas após a retirada de linhas sem informações(NA) no campo essencial PCR_RESUL.", c3))

rm(data2)

###########################################################################

data4 <- data3 %>%
		select(DT_NOTIFIC, DT_SIN_PRI, DT_DIGITA, SEM_NOT, CO_MUN_RES, CO_MUN_NOT, CS_SEXO, NU_IDADE_N, TP_IDADE, SUPORT_VEN, HOSPITAL, DT_INTERNA, UTI, DT_ENTUTI, DT_SAIDUTI, EVOLUCAO, VACINA_COV, DOSE_1_COV, DOSE_2_COV, DOSE_REF, LAB_PR_COV, POS_PCROUT, PCR_SARS2, PCR_RESUL, CLASSI_FIN) %>%
		mutate(IDADE_TP = case_when(TP_IDADE == 1 ~ 'D',
 						 TP_IDADE == 2 ~ 'M',
						 TP_IDADE == 3 ~ 'A')) %>%
		mutate(IDADE = paste0(as.character(NU_IDADE_N),IDADE_TP)) 

data4$IDADE <- replace(data4$IDADE, grep("M|D", data4$IDADE, ignore.case = TRUE, perl = TRUE), "0A")
data4$IDADE <- as.numeric(gsub("A", "", data4$IDADE, ignore.case = TRUE, perl = TRUE))

data4$DT_SIN_PRI <- as.Date(data4$DT_SIN_PRI, format = "%d/%m/%Y") 
data4$DT_NOTIFIC <- as.Date(data4$DT_NOTIFIC, format = "%d/%m/%Y")
data4$DT_DIGITA <- as.Date(data4$DT_DIGITA, format = "%d/%m/%Y")
data4$DOSE_1_COV <- as.Date(data4$DOSE_1_COV, format = "%d/%m/%Y") 
data4$DOSE_2_COV <- as.Date(data4$DOSE_2_COV, format = "%d/%m/%Y")
data4$DOSE_REF <- as.Date(data4$DOSE_REF, format = "%d/%m/%Y") 
data4$DT_INTERNA <- as.Date(data4$DT_INTERNA, format = "%d/%m/%Y")
data4$DT_ENTUTI <- as.Date(data4$DT_ENTUTI, format = "%d/%m/%Y") 
data4$DT_SAIDUTI <- as.Date(data4$DT_SAIDUTI, format = "%d/%m/%Y")

rm(data3)

##############################################################################

data5 <- data4 %>%
		mutate(DIAS_ULT_DOSE = ifelse(is.na(DOSE_REF) | DOSE_REF > DT_NOTIFIC, ifelse(is.na(DOSE_2_COV) | DOSE_2_COV > DT_NOTIFIC, ifelse(is.na(DOSE_1_COV) | DOSE_1_COV > DT_NOTIFIC, NA, DT_NOTIFIC - DOSE_1_COV), DT_NOTIFIC - DOSE_2_COV), DT_NOTIFIC - DOSE_REF)) %>%
		mutate(PERM_UTI = DT_SAIDUTI - DT_ENTUTI) %>%		
		filter( is.na(DIAS_ULT_DOSE) | DIAS_ULT_DOSE < max(DT_DIGITA) - as.Date("2021-01-17")) 
		

c5 <- count(data5) #Número de linhas após a retirada de linhas que continham número de dias superior à data da primeira vacina de covid aplicada no Brasil.

log_print(sprintf("A tabela apresenta %s linhas após a retirada de linhas que continham número de dias superior à data da primeira vacina de covid aplicada no Brasil.", c5))

#############################################################################
#Criar coluna com ano e coluna com grupo de idade

data6 <- data5 %>% mutate(GRUPO_IDADE = case_when(IDADE <= 10 ~ '0-10',
 						    IDADE >= 11 & IDADE <= 20 ~ '11-20',
						    IDADE >= 21 & IDADE <= 30 ~ '21-30',
						    IDADE >= 31 & IDADE <= 40 ~ '31-40',
						    IDADE >= 41 & IDADE <= 50 ~ '41-50',
						    IDADE >= 51 & IDADE <= 60 ~ '51-60',
						    IDADE >= 61 & IDADE <= 70 ~ '61-70',
						    IDADE >= 71 & IDADE <= 80 ~ '71-80',
						    IDADE >= 81 & IDADE <= 90 ~ '81-90',
						    IDADE >= 91 & IDADE <= 100 ~ '91-100',
						    IDADE >100 ~ '>100')) %>%
			 mutate(ANO = year(DT_NOTIFIC), SEXO = CS_SEXO) %>%
			 filter(! SEXO == "I") %>%
			 select(DT_NOTIFIC, DT_SIN_PRI, DT_DIGITA, ANO, SEM_NOT, CO_MUN_RES, SEXO, IDADE, GRUPO_IDADE, SUPORT_VEN, HOSPITAL, DT_INTERNA, UTI, DT_ENTUTI, DT_SAIDUTI, PERM_UTI, EVOLUCAO, VACINA_COV, DOSE_1_COV, DOSE_2_COV, DOSE_REF, DIAS_ULT_DOSE, POS_PCROUT, PCR_SARS2, PCR_RESUL, CLASSI_FIN) 

c6 <- count(data6) #Número de linhas após a retirada de linhas que continham sexo indeterminado no campo SEXO.

log_print(sprintf("A tabela apresenta %s linhas após a retirada de linhas que continham sexo indeterminado no campo SEXO.", c6))

##################################################################################
#Retirada de semanas epidemiológicas erradas


lista <- data6 %>% group_by(ANO, SEM_NOT) %>% count()
"%ni%" <- Negate("%in%")
escolha_in <- menu(lista$SEM_NOT, title = "Selecione qual semana epidemiológica deseja retirar ou 0 se desejar encerrar o menu.")
escolha <- lista[escolha_in,]
data7 <- data6[!(ANO == escolha[[1]] & SEM_NOT == escolha[[2]])]
	while (0 %ni% escolha_in){
		lista <- data7 %>% group_by(ANO, SEM_NOT) %>% count()
		escolha_in <- menu(lista$SEM_NOT, title = "Selecione qual semana epidemiológica deseja retirar ou 0 se desejar encerrar o menu.")
			if (escolha_in != 0) {
				escolha <- lista[escolha_in,]
				data7 <- data7[!(ANO == escolha[[1]] & SEM_NOT == escolha[[2]])]
			}else{
			}
	}

c7 <- count(data7) #Número de linhas após a retirada de semanas epidemiológicas específicas.
 
log_print(sprintf("A tabela apresenta %s linhas após a retirada de semanas epidemiológicas específicas.", c7))

##############################################################################
#Formatação dos labels das colunas

data8 <- data7 %>% mutate(SUPPORT_VEN = case_when(SUPORT_VEN == 1 ~ 'Yes',
								 SUPORT_VEN == 2 ~ 'Yes',
								 SUPORT_VEN == 3 ~ 'No',
								 SUPORT_VEN == 9 ~ 'Unknown'),
				 HOSPITAL = case_when(HOSPITAL == 1 ~ 'Yes',
							    HOSPITAL == 2 ~ 'No',
							    HOSPITAL == 9 ~ 'Unknown'),
				 ICU = case_when(UTI == 1 ~ 'Yes',
						     UTI == 2 ~ 'No',
						     UTI == 9 ~ 'Unknown'),
				 VACCINE_COV = case_when(VACINA_COV == 1 ~ 'Vaccinated',
								VACINA_COV == 2 ~ 'Unvaccinated',
								VACINA_COV == 9 ~ 'Unknown'),
				 DEATH = case_when(EVOLUCAO == 1 ~ 'Survived',
							    EVOLUCAO == 2 ~ 'Died',
							    EVOLUCAO == 3 ~ 'Unknown',
							    EVOLUCAO == 9 ~ 'Unknown')) %>%
				select(DT_NOTIFIC, DT_SIN_PRI, DT_DIGITA, ANO, SEM_NOT, CO_MUN_RES, SEX = SEXO, 
						AGE = IDADE, AGE_GROUP = GRUPO_IDADE, 
						DT_INTERNA, DT_ENTUTI, DT_SAIDUTI,
						PERM_UTI, VACCINE_COV, DOSE_1_COV,
						DOSE_2_COV, DOSE_REF, DIAS_ULT_DOSE,
						PCR_RESUL, PCR_SARS2, CLASSI_FIN,
						HOSPITAL, SUPPORT_VEN, ICU, DEATH)  

###############################################################################
#descrever o conjunto de dados completo

log_print("Descrição do conjunto de dados completo.")

colunas <- c("SEX", "AGE_GROUP", "VACCINE_COV" )

for (col in colunas){
	d <- data8 %>%  
			group_by(!!as.name(col)) %>%
 			summarise(cnt = n()) %>%
 			mutate(freq = formattable::percent(cnt / sum(cnt))) %>%
			arrange(desc(freq)) 
	log_print(as.data.frame(d))
}

dataset1 <- data8[ ,.(DOSE_1_COV = !is.na(DOSE_1_COV), DOSE_2_COV = !is.na(DOSE_2_COV), DOSE_REF = !is.na(DOSE_REF))] 
colunas <- c("DOSE_1_COV", "DOSE_2_COV", "DOSE_REF")

for (col in colunas){
	d <- dataset1 %>%
		group_by(!!as.name(col)) %>%
 			summarise(cnt = n()) %>%
 			mutate(freq = formattable::percent(cnt / sum(cnt))) %>%
			arrange(desc(freq)) 
	log_print(as.data.frame(d))
}


colunas <- c("HOSPITAL", "SUPPORT_VEN", "ICU", "DEATH") 

for (col in colunas){
	d <- data8 %>%  
			group_by(!!as.name(col)) %>%
 			summarise(cnt = n()) %>%
 			mutate(freq = formattable::percent(cnt / sum(cnt))) %>%
			arrange(desc(freq)) 
	log_print(as.data.frame(d))
}



###################Capitais escolhidas################################
capitais <- c("Aracaju", "Belem", "BeloHorizonte", "BoaVista", "Brasilia", "Fortaleza", "Goiania", "Macapa", "Manaus", "Palmas", "PortoVelho", "RiodeJaneiro", "SaoPaulo")
capitais_name <- c("Aracaju", "Belém", "Belo Horizonte", "Boa Vista", "Brasília", "Fortaleza", "Goiânia", "Macapá", "Manaus", "Palmas", "Porto Velho", "Rio de Janeiro", "São Paulo")
cod_ibge <- c(280030, 150140, 310620, 140010, 530010, 230440, 520870, 160030, 130260, 172100, 110020, 330455, 355030) 
delta_ini <- c("2021-09-19", "2021-10-10", "2021-08-29", "2021-08-29", "2021-09-26", "2021-10-03", "2021-09-19", "2021-09-26", "2021-10-17", "2021-08-29", "2021-09-26", "2021-09-19", "2021-08-29")
delta_fim <- c("2021-12-11", "2021-12-11", "2021-12-11", "2021-10-09", "2021-11-06", "2021-12-04", "2021-11-06", "2021-12-18", "2021-12-04", "2021-12-18", "2021-12-11", "2021-10-30", "2021-12-11")
omicron_ini <- c("2022-01-09", "2022-01-09", "2021-12-26", "2022-01-09", "2022-01-02", "2022-01-02", "2021-12-26", "2022-01-16", "2022-01-09", "2022-01-09", "2022-01-02", "2021-12-19", "2021-12-26")
omicron_fim <- c("2022-02-12", "2022-03-05", "2022-02-26", "2022-02-12", "2022-02-12", "2022-02-12", "2022-02-19", "2022-03-05", "2022-02-12", "2022-03-05", "2022-02-19", "2022-02-26", "2022-02-19")

log_print(as.data.frame(d <- data.frame(capitais = capitais, cod_ibge = cod_ibge, delta_ini = delta_ini, delta_fim = delta_fim, omicron_ini = omicron_ini, omicron_fim = omicron_fim)))
######################################################################
#Criar arquivos para a meta-análise

dataset_pos <- data7 %>% filter( PCR_RESUL == 1 & PCR_SARS2 == 1 & CLASSI_FIN == 5)
#dataset_neg <- data7 %>% filter( is.na(PCR_SARS2) & CLASSI_FIN %in% c(1, 2, 3))


#count(dataset_pos %>% filter (CO_MUN_RES %in% ibge_graph)) #tamanho do dataset usado no artigo

df_meta <- data.frame(city = character(),
				Control_group = character(),
				Case_group = character(),
				Delta_sim = integer(),
				Delta_total = integer(),
				Omicron_sim = integer(),
				Omicron_total = integer())


dataset_Vac <- dataset_pos %>% filter(VACINA_COV == 1)
dataset_Nvac <- dataset_pos %>% filter(VACINA_COV == 2)

datasets <- c("dataset_pos", "dataset_Vac", "dataset_Nvac")

for (dataset in datasets){
	for(i in 1:length(capitais)){
		d <- get(dataset)
		datain <- d[which(d$DT_NOTIFIC >= delta_ini[i] & d$DT_NOTIFIC <= delta_fim[i] &  d$CO_MUN_RES == cod_ibge[i]), ] %>% select(SUPORT_VEN, UTI, EVOLUCAO, SEXO)
		LEGENDA <- sort(unique(unlist(datain)))
		freq <- sapply(datain, 
               function(x) table(factor(x, levels = LEGENDA, 
                                        ordered = TRUE)))
		df <- cbind(as.data.frame(LEGENDA), as.data.frame(freq)) 
		
		log_print(sprintf("Tabela de %s de %s a %s.", capitais_name[i], delta_ini[i], delta_fim[i]))
		log_print(df)
		write_xlsx(df, paste0("freq_",dataset,"_", capitais[i], "_", delta_ini[i], "_", delta_fim[i], ".xlsx"))

		datafin <- d[which(d$DT_NOTIFIC >= omicron_ini[i] & d$DT_NOTIFIC <= omicron_fim[i] &  d$CO_MUN_RES == cod_ibge[i]), ] %>% select(SUPORT_VEN, UTI, EVOLUCAO, SEXO)
		LEGENDA <- sort(unique(unlist(datafin)))
		freq <- sapply(datafin, 
               function(x) table(factor(x, levels = LEGENDA, 
                                        ordered = TRUE)))
		df2 <- cbind(as.data.frame(LEGENDA), as.data.frame(freq))
		log_print(sprintf("Tabela de %s de %s a %s.", capitais_name[i], omicron_ini[i], omicron_fim[i]))
		log_print(df2)
		write_xlsx(df2, paste0("freq_", dataset, "_", capitais[i], "_", omicron_ini[i], "_", omicron_fim[i], ".xlsx"))

	}
}

